%----------------------------------------------------------
%
% Programa para desenhar os diagramas de Bode da haste
% flexivel.
%
% Autores: Prof. Jose Paulo V. S. da Cunha
%          Igor Fonseca Albuquerque
%
% Universidade do Estado do Rio de Janeiro
% Faculdade de Engenharia
% Departamento de Eletronica e Telecomunicacoes
%
% Disciplina: Controle e Servomecanismos II
%
% Rio de Janeiro, 23 de outubro de 2014.
%
% Nota: Os alunos deverao incluir neste programa os coeficientes
% para calibracao dos sensores.
%
%----------------------------------------------------------

faixa=2*pi*[0.1 20];  % Faixa de frequencia de interesse (rad/s).

figure(1);
chirp_haste_u; % Dados de entrada: controle (V).
u = PLOT_DATA;

figure(2);
chirp_haste_theta; % Dados de entrada: posicao angular theta do eixo (V).
y1 = PLOT_DATA;

figure(3);
chirp_haste_alpha; % Dados de entrada: angulo alpha da haste (V).
y2 = PLOT_DATA;

h = client_ts; % Periodo de amostragem.

% Transformadas de Fourier dos sinais:

U = fft(u);
Y1 = fft(y1);
Y2 = fft(y2);

% Estimativa da resposta em frequencia P1(jw):

P1 = U .* Y1 ./ U.^2;
MagData1 = 20*log10(abs(P1));
PhaseData1 = angle(P1)*(180/pi);

% Estimativa da resposta em frequencia P2(jw):

P2 = U .* Y2 ./ U.^2;
MagData2 = 20*log10(abs(P2));
PhaseData2 = angle(P2)*(180/pi);

N = length(u);
N2 = floor(N/2);
FreqData = 2*pi*[0:N-1]/(N*h); % Frequencia em rad/s.

% Desenha os diagramas de Bode:

figure(4);

subplot(211); semilogx(FreqData(1:N2),MagData1(1:N2));
xlim (faixa);
ylabel('Magnitude_1 (dB)');
xlabel('w (rad/s)');

subplot(212); semilogx(FreqData(1:N2),PhaseData1(1:N2));
ylabel('Fase_1 (graus)');
xlim (faixa);
xlabel('w (rad/s)');

figure(5);

subplot(211); semilogx(FreqData(1:N2),MagData2(1:N2));
xlim (faixa);
ylabel('Magnitude_2 (dB)');
xlabel('w (rad/s)');

subplot(212); semilogx(FreqData(1:N2),PhaseData2(1:N2));
ylabel('Fase_2 (graus)');
xlim (faixa);
xlabel('w (rad/s)');
